%% Truncation and Round-off Error in a Fourier Series
% This program calculates the unsteady oxygen distribution in skeletal 
% muscle tissue.

%% Variables
clear all
Gamma1 = 50; %uM/s
Gamma2 = 260; %uM/s
L = 0.006; %cm
No= 87; %uM
D = 1.5d-5; %cm2/s
maxnoofterms = 15;
N(1:maxnoofterms) = 0; %Oxygen concentration as a function of n and t
t = [0:0.01:1.0]';
x = L/2;
%% O2 distribution
% Store summation as a matrix with rows indicating different t and columns
% indicating different n
sumofterms(1:length(t),1:maxnoofterms)= 0;

%Pre-calculating known terms
expterm = pi.*pi.*D.*t./L./L; %vector of size 1:length(t)
sinterm = pi*x/L;
steadyN = No - Gamma2*x*(L-x)/2/D;
transientN = 4*(Gamma2 - Gamma1)*L*L/D;

for n = 1:2:maxnoofterms
    term = exp(-n.*n.*expterm).*sin(n.*sinterm)./((n.*pi)^3); %vector
    if n > 1
        sumofterms(:,n) = sumofterms(:,n-2) + term;
    else
        sumofterms(:,1) = term;
    end
end
N = steadyN  + transientN*sumofterms; % N is a dyad

%% Plots

% Plot of N vs. t for x = L/2 and for n = 1, 3, 5, 7
figure;
subplot(1,2,1) % Figure A: Upto 1 second
plot(t,N(:,1),'k-',t,N(:,3),'k:',t,N(:,5),'k-.',t,N(:,7),'k--', ...
    'LineWidth',2)
xlabel('{\itt} in s','FontSize',16)
ylabel('{\itN}  at {\itx} = {\itL}/2 in \muM','FontSize',16)
set(gca,'FontSize',16,'LineWidth',2)
legend('{\itn} = 1','{\itn} = 3','{\itn} = 5','{\itn} = 7')

subplot(1,2,2)%Figure B: Upto 0.1 second
plot(t(1:11),N(1:11,1),'k-',t(1:11),N(1:11,3),'k:',t(1:11),N(1:11,5), ...
    'k-.',t(1:11),N(1:11,7),'k--','LineWidth',2)
xlabel('{\itt} in s','FontSize',16)
set(gca,'FontSize',16,'LineWidth',2)
legend('{\itn} = 1','{\itn} = 3','{\itn} = 5','{\itn} = 7')
axis([0 0.1 50 75])

%Plot of N for varying n at x = L/2 and t = 0.05 s
figure;
plot([1:2:maxnoofterms],N(6,[1:2:maxnoofterms]),'ko','LineWidth',2) 
xlabel('number of terms {\itn}','FontSize',16)
ylabel('{\itN} in \muM ({\itx} = {\itL}/2, {\itt} = 0.05 s)','FontSize',16)
set(gca,'FontSize',16,'LineWidth',2)
axis([0 15 60 63])