%% Truncation Error versus Round-off Error
% Using the forward finite difference approximation, the rate of change in
% specific growth rate (Monod kinetics) is estimated for a range of step
% sizes. 

%% Variables
h(1) = 0.1;     %initial step size
mumax = 1.0;    %hr-1
Ks = 0.5;       %g/L
s0 = 1.0;       %g/L substrate concentration
                % the specific growth rate
                
% Calculating specific growth rate                
mus0 = mumax*s0/(Ks + s0); % specific growth rate at s0

% Calculating rate of change of specific growth rate
mudash = mumax*Ks/((Ks+s0)^2); %true value at s0

% Determining a range of step sizes of decreasing orders of magnitude
for k = 2:15
    h(k) = h(k-1)/10;
end
%% Forward finite difference approximation
s = s0 + h; % vector of incrementally larger values of s
mus = mumax.*s./(Ks + s); % vector of specific growth rates at s
forwarddiff = (mus - mus0)./h; %vector of approximations of first-order derivative
relativeerr = abs((forwarddiff - mudash))./abs(mudash); %vector of relative errors

%% Plotting the relative error in approximation of first-order derivative
figure;
loglog(h, relativeerr,'k*','LineWidth',2)
set(gca,'LineWidth',2,'FontSize',16)
xlabel('Step size {\ith}','FontSize',16)
ylabel('Relative Error','FontSize',16)