function x = Gaussianbasic(A, b)
% Uses basic Gaussian elimination with backward substitution to solve a set
% of n linear equations in n unknowns.

% Input Variables
% A is the coefficient matrix
% b is the constants vector

% Output Variables
% x is the solution

Aug = [A b];
[n, ncol] = size(Aug);
x = zeros(n,1); % initializing the column vector x

% Elimination steps
for k = 1:n-1
	pivot = Aug(k,k);
	for row = k + 1:n
		m = Aug(row,k)/pivot;
		Aug(row,k+1:ncol) = Aug(row,k+1:ncol) - m*Aug(k,k+1:ncol);
	end
end

% Backward substitution steps
x(n)=Aug(n,ncol)/Aug(n,n);
for k = n - 1:-1:1
    x(k) = (Aug(k,ncol) - Aug(k,k+1:n)*x(k+1:n))/Aug(k,k); 
    % Note the inner product
end