function x = Gaussianpivoting(A, b)
% Uses Gaussian elimination with pivoting to solve a set
% of n linear equations in n unknowns.

% Input Variables
% A is the coefficient matrix
% b is the constants vector

% Output Variables
% x is the solution

Aug = [A b];
[n, ncol] = size(Aug);
x = zeros(n,1); % initializing the column vector x

% Elimination with Pivoting
for k = 1:n-1
    [maxele, l] = max(abs(Aug(k:n,k))); 
    % l is the location of max value between k and n
    p = k + l - 1; % row to be interchanged with pivot row
    if (p ~= k)% if p is not equal to k
        Aug([k p],:) = Aug([p k],:); % array index used for efficient swap
    end
    pivot = Aug(k,k);
	for row = k + 1:n
		m = Aug(row,k)/pivot;
		Aug(row,k+1:ncol) = Aug(row,k+1:ncol) - m*Aug(k,k+1:ncol);
	end
end

% Backward substitution steps
x(n)=Aug(n,ncol)/Aug(n,n);
for k = n - 1:-1:1
    x(k) = (Aug(k,ncol) - Aug(k,k+1:n)*x(k+1:n))/Aug(k,k); 
    % Note the inner product
end