function bisectionmethod(func,ab, tolx, tolfx)
% Bisection algorithm used to solve a nonlinear equation in x

% Input variables
% func : non-linear function 
% ab   : bracketing interval [a, b]
% tolx : tolerance for error in estimating root
% tolfx: tolerance for error in function value at solution

% Other variables
maxloops = 50; % maximum number of iterations allowed

% Root-containing interval [a b]
a = ab(1); 
b = ab(2); 
fa = feval(func, a); % feval evaluates func at point a
fb = feval(func, b); % feval evaluates func at point b
% Min number of iterations required to meet criterion of Tolx
minloops = ceil(log(abs(b-a)/tolx)/log(2)); 
         % ceil rounds towards +Inf 

fprintf('Min iterations for reaching convergence = %2d \n',minloops)
fprintf(' i     x      f(x)  \n'); % \n is carriage return

% Iterative solution scheme
for i = 1:maxloops
    x = (a+b)/2; % mid-point of interval   
    fx = feval(func,x);
    fprintf('%3d %5.4f %5.4f \n',i,x,fx);
    if (i >= minloops && abs(fx) < tolfx) 
        break % Jump out of the for loop
    end
    if (fx*fa < 0)  % [a x] contains root
        fb = fx; b = x;
    else            % [x b] contains root
        fa = fx; a = x;
    end
end
