function [f fderiv] = packedbedreactor(sout)
% Calculation of mass balance equation for immobilized enzyme fixed bed
% reactor

% Input Variable
% sout : substrate concentration in outlet stream 

% Constants
sfeed = 0.073;  % mg/ml : substrate concentration at inlet
q = 80;         % ml/min : flowrate 
dia = 2;        % cm : diameter of reactor tube
Ac = pi/4*dia^2;% cross-sectional area of reactor
porosity = 0.4; % fraction of unoccupied volume in reactor
l = 10;         % cm : length of reactor
K = 0.5;        % partition coefficient
vmax = 31/60;   % mg/ml/min : maximum reaction velocity
Km = 0.022;     % mg/ml : Michaelis constant
eff = 0.6;      % reaction efficiency

f = Km*log(sfeed/sout) + K*(sfeed - sout) - ...
    (1-porosity)*Ac*l*K*vmax*eff/q;
fderiv = -Km/sout - K;