function regulafalsimethod(func, x0x1, tolx, tolfx)
% Regula-Falsi method used to solve a nonlinear equation in x

% Input variables
% func : non-linear function 
% x0x1 : bracketing interval [x0, x1]
% tolx : tolerance for error in estimating root
% tolfx: tolerance for error in function value at solution

% Other variables
maxloops = 50;
% Root-containing interval [x0, x1]
x0 = x0x1(1); x1 = x0x1(2); 
fx0 = feval(func, x0); fx1 = feval(func, x1);
fprintf(' i     x      f(x)  \n'); % \n is carriage return
xold = x1;

% Iterative solution scheme
for i = 1:maxloops
    %intersection of secant line with x-axis
    x2 = x1 - fx1*(x1 - x0)/(fx1 - fx0);    
    fx2 = feval(func,x2);
    fprintf('%2d %7.6f %7.6f \n',i,x2,fx2);
    if (abs(x2 - xold) <=tolx && abs(fx2) < tolfx) 
        break % Jump out of the for loop
    end
    if (fx2*fx0 < 0)  % [x0 x2] contains root
        fx1 = fx2; x1 = x2;
    else            % [x2 x1] contains root
        fx0 = fx2; x0 = x2;
    end
    xold = x2;
end



