function R = Romberg_integration(integrandfunc, a, b, maxlevel)
% This function uses Romberg integration to calculate an integral 
% when the integrand function is available in analytical form.

% Input variables
% integrandfunc : function that calculates the integrand
% a : lower limit of integration
% b : upper limit of integration
% maxlevel : maximum level of integration

% Output variables
% I : value of integral

%Initializing variables
R(1:maxlevel,1:maxlevel) = 0;
j = [1:maxlevel];
n = 2.^(j-1); % number of subintervals vector

% Generating the first column of approximations using trapezoidal rule
for l = 1 : maxlevel
    R(l, 1) = trapezoidal_rule(integrandfunc, a, b, n(l));
end

%Generating approximations for columns 2 to maxlevel
for k = 2 : maxlevel
    for l = k : maxlevel
        R(l, k) = R(l, k - 1) + (R(l, k - 1) - R(l - 1, k - 1))/(4^(k - 1) - 1);
    end
end