% This program uses fminsearch to minimize the error of nonlinear 
% least-squares regression of the unimodal Gaussian model to the pixel 
% intensities data at a cell synapse.
% To execute this program place the data files into the same directory in
% which this m-file is located.

% Variables
global data % matrix containing pixel intensity data
Nfiles = 4; % number of data files to be analyzed, maximum allowed is 999

for i = 1:Nfiles
    num = num2str(i);
    if length(num) == 1
        filename = ['data00',num,'.dat'];
    elseif length(num) == 2
        filename = ['data0',num,'.dat'];
    else
        filename = ['data',num,'.dat'];
    end
    data = load(filename);
    p = fminsearch('PixelSSE',[15,5,150,110]);
    
    % Compute model
    x = 1:.1:length(data);
    y = p(3)/sqrt(2*pi*p(2)^2)* ...
        exp(-(x - p(1)).^2/(2*p(2)^2)) + p(4);
    
    % Compare data with the Gaussian model
    figure(i)
    plot(data(:,1),data(:,2),'ko',x,y,'k-')
    xlabel('{\itx}', 'FontSize',24)
    ylabel('Intensity', 'FontSize',24)
    set(gca, 'LineWidth',2, 'FontSize',20)
end
