% Bootstrap routine is performed to estimate the covariance matrix
clear all
global S
global R

% Data
% Plasma leptin concentration
Sorig = [0.75; 1.18; 1.47; 1.61; 1.64; 5.26; 5.88; 6.25; 8.33; ...
    10.0; 11.11; 20.0; 21.74; 25.0; 27.77; 35.71];
% Renal Leptin Uptake
Rorig = [0.11; 0.204; 0.22; 0.143; 0.35; 0.48; 0.37; 0.48; 0.83; ...
    1.25; 0.56; 3.33; 2.5; 2.0; 1.81; 1.67]; 

% Other variables  
N = length(Sorig); % size of original data set
m = 10; % number of derived data sets of size N

% Bootstrap to generate m data sets
dataset(1:N,2,m) = 0;
for i = 1:m
    for j = 1:N
        randomno = floor(rand()*N + 1);
        dataset(j,:,i) = [Sorig(randomno) Rorig(randomno)];
    end
end
 
% Perform m nonlinear regressions
pdistribution(1:m, 1:2) = 0; % preallocating m sets of parameter 
                             % values
for i = 1:m
    S = dataset(:,1,i);
    R = dataset(:,2,i);
    p0 = [1.732, 10.87]; % initial guess value obtained from Box 3.9A
    p1 = fminunc('SSEleptinuptake', p0);
    pdistribution(i,:) = p1;
end
        
% Calculate the covariance matrix
sigma = cov(pdistribution);
muRmax = mean(pdistribution(:,1));
muKm = mean(pdistribution(:,2));
