%% Pharmacokinetic and toxicity studies of AZT
% Performs nonlinear regression using fminsearch to find the parameters for 
% the maternal and detal comaprtments.
clear all
global data

%% Maternal compartment
% Data
time = [0; 1; 3; 5; 10; 20; 40; 50; 60; 90; 120; 150; 180; 210; 240];
AZTconc = [0; 1.4; 4.1; 4.5; 3.5; 3.0; 2.75; 2.65; 2.4; 2.2; 2.15; 2.1; 2.15; 1.8; 2.0];
data = [time, AZTconc];

pm = fminsearch('SSRpharmacokineticsofAZTm',[3.8, 0.2, 0.1])

% Nonlinear model - Simplex algorithm
timemodel = time(1):time(end);
AZTconcmodel = pm(1)*pm(2)/(pm(2) - pm(3))*(exp(-pm(3).*timemodel)-exp(-pm(2).*timemodel));

%% Plotting the figure 
figure;
plot(time, AZTconc, 'ko', timemodel, AZTconcmodel, 'k-')
set(gca, 'FontSize',16','LineWidth',2)
xlabel('{\itt} in min')
ylabel('{\itC_m} in mM')
legend('observed values','nonlinear model')

%% Fetal compartment
clear all
global data
% Data
time = [0; 1; 5; 10; 20; 40; 50; 60; 90; 120; 150; 180; 210; 240];
AZTconc = [0; 0.1; 0.4; 0.8; 1.1; 1.2; 1.4; 1.35; 1.6; 1.7; 1.9; 2.0; 1.95; 2.2];
data = [time, AZTconc];

pf = fminsearch('SSRpharmacokineticsofAZTf',[2, 0.1])

% Nonlinear model - Simplex algorithm
timemodel = time(1):time(end);
AZTconcmodel = pf(1)*(1 - exp(-pf(2).*timemodel));
%% Plotting the figure 
figure;
plot(time, AZTconc, 'ko', timemodel, AZTconcmodel, 'k-')
set(gca, 'FontSize',16','LineWidth',2)
xlabel('{\itt} in min')
ylabel('{\itC_f} in mM')
legend('observed values','nonlinear model')